@@ -1,9 +1,13 @@
+try:
+    from importlib import import_module
+except ImportError:
+    from django.utils.importlib import import_module
+
 from classytags.arguments import Argument, Flag
 from classytags.core import Tag, Options
 from classytags.parser import Parser
 from django import template
 from django.conf import settings
-from django.utils.importlib import import_module
 
 from sekizai.helpers import get_varname
 
@@ -78,12 +82,12 @@ class RenderBlock(Tag):
             return nodelist.render(context)
         rendered_contents = nodelist.render(context)
         varname = get_varname()
-        data = context[varname][name].render()
+        data = '\n'.join(context[varname][name])
         if postprocessor:
             func = import_processor(postprocessor)
             data = func(context, data, name)
         return '%s\n%s' % (data, rendered_contents)
-register.tag(RenderBlock)
+register.tag('render_block', RenderBlock)
 
 
 class AddData(SekizaiTag):
@@ -98,7 +102,7 @@ class AddData(SekizaiTag):
         varname = get_varname()
         context[varname][key].append(value)
         return ''
-register.tag(AddData)
+register.tag('add_data', AddData)
 
 
 class WithData(SekizaiTag):
@@ -123,7 +127,7 @@ class WithData(SekizaiTag):
         inner_contents = inner_nodelist.render(context)
         context.pop()
         return '%s\n%s' % (inner_contents, rendered_contents)
-register.tag(WithData)
+register.tag('with_data', WithData)
 
 
 class Addtoblock(SekizaiTag):
@@ -147,4 +151,4 @@ class Addtoblock(SekizaiTag):
         varname = get_varname()
         context[varname][name].append(rendered_contents)
         return ""
-register.tag(Addtoblock)
+register.tag('addtoblock', Addtoblock)
